@@ -6,11 +6,11 @@ use std::io::{Read, Write};
 use std::path::{Path, PathBuf};
 use std::rc::Rc;
 
+use anyhow::anyhow;
 use cargo::core::{Dependency, PackageId, Summary, Verbosity, Workspace};
 use cargo::ops::{update_lockfile, UpdateOptions};
 use cargo::util::errors::CargoResultExt;
 use cargo::util::{CargoResult, Config};
-use failure::err_msg;
 use semver::{Identifier, Version, VersionReq};
 use tempfile::{Builder, TempDir};
 use toml::value::Table;
@@ -43,7 +43,7 @@ impl<'tmp> TempProject<'tmp> {
         let temp_dir = Builder::new().prefix("cargo-outdated").tempdir()?;
         let manifest_paths = manifest_paths(orig_workspace)?;
         let mut tmp_manifest_paths = vec![];
-        
+
         for from in &manifest_paths {
             // e.g. /path/to/project/src/sub
             let mut from_dir = from.clone();
@@ -81,12 +81,30 @@ impl<'tmp> TempProject<'tmp> {
                 write!(cargo_toml, "{}", om_serialized)?;
             }
 
+            // if build script is specified in the original Cargo.toml (from links or build) remove it as we do not need
+            // it for checking dependencies
+            if om.package.contains_key("links") {
+                om.package.remove("links");
+                let om_serialized = ::toml::to_string(&om).expect("Cannot format as toml file");
+                let mut cargo_toml = OpenOptions::new().read(true).write(true).truncate(true).open(&dest)?;
+                write!(cargo_toml, "{}", om_serialized)?;
+            }
+
+            if om.package.contains_key("build") {
+                om.package.remove("build");
+                let om_serialized = ::toml::to_string(&om).expect("Cannot format as toml file");
+                let mut cargo_toml = OpenOptions::new().read(true).write(true).truncate(true).open(&dest)?;
+                write!(cargo_toml, "{}", om_serialized)?;
+            }
+
             let lockfile = from_dir.join("Cargo.lock");
             if lockfile.is_file() {
                 dest.pop();
                 dest.push("Cargo.lock");
                 fs::copy(lockfile, dest)?;
             }
+
+
         }
 
         // virtual root
@@ -100,6 +118,12 @@ impl<'tmp> TempProject<'tmp> {
             }
         }
 
+        //.cargo/config 
+        if workspace_root.join(".cargo/config").is_file() {
+            fs::create_dir_all( temp_dir.path().join(".cargo"))?;
+            fs::copy(&workspace_root.join(".cargo/config"), temp_dir.path().join(".cargo/config"))?;
+        }
+
         let relative_manifest = String::from(&orig_manifest[workspace_root_str.len() + 1..]);
         let config = Self::generate_config(temp_dir.path(), &relative_manifest, options)?;
         
@@ -123,13 +147,21 @@ impl<'tmp> TempProject<'tmp> {
             .chain_err(|| "Cargo couldn't get the current directory of the process")?;
 
         let homedir = ::cargo::util::homedir(&cwd).ok_or_else(|| {
-            err_msg(
+            anyhow!(
                 "Cargo couldn't find your home directory. \
                  This probably means that $HOME was not set.",
             )
         })?;
         let mut cwd = Path::new(root).join(relative_manifest);
         cwd.pop();
+        
+        // Check if $CARGO_HOME is set before capturing the config environment 
+        // if it is, set it in the configure options 
+        let cargo_home_path = match std::env::var_os("CARGO_HOME") {
+            Some(path) => Some(std::path::PathBuf::from(path)),
+            None => None
+        };
+
         let mut config = Config::new(shell, cwd, homedir);
         config.configure(
             0,
@@ -138,11 +170,12 @@ impl<'tmp> TempProject<'tmp> {
             } else {
                 Some(true)
             },
-            &options.flag_color,
+            options.flag_color.as_deref(),
             options.frozen(),
             options.locked(),
             false,
-            &None,
+            &cargo_home_path,
+            &[],
             &[],
         )?;
         Ok(config)
@@ -433,12 +466,18 @@ impl<'tmp> TempProject<'tmp> {
                     }
                 }
                 Value::Table(ref t) => {
-                    let name = match t.get("package") {
+                    let mut name = match t.get("package") {
                         Some(&Value::String(ref s)) => s,
                         Some(_) => panic!("'package' of dependency {} is not a string", dep_key),
                         None => &dep_key,
                     };
 
+                    let mut orig_name = "";
+                    if t.contains_key("package") {
+                        orig_name = name;
+                        name = &dep_key;
+                    }
+
                     if !(version_to_latest || t.contains_key("features")) {
                         continue;
                     }
@@ -462,7 +501,7 @@ impl<'tmp> TempProject<'tmp> {
                         _ => None,
                     };
                     let r_summary = self.find_update(
-                        &name,
+                        if orig_name == "" { &name } else { &orig_name },
                         package_name,
                         requirement,
                         workspace,
@@ -615,9 +654,16 @@ fn manifest_paths(elab: &ElaborateWorkspace<'_>) -> CargoResult<Vec<PathBuf>> {
         visited.insert(pkg_id);
         let pkg = &elab.pkgs[&pkg_id];
         let pkg_path = pkg.root().to_string_lossy();
-        if pkg_path.starts_with(workspace_path) {
-            manifest_paths.push(pkg.manifest_path().to_owned());
-        }
+        let cargo_home_path = match std::env::var_os("CARGO_HOME") {
+             Some(path) => path.into_string().expect("Error getting string from OsString"),
+             None => "".to_string(),
+         };
+
+         if pkg_path.starts_with(workspace_path) {
+             if !pkg_path.starts_with(&cargo_home_path){
+                 manifest_paths.push(pkg.manifest_path().to_owned());
+             }
+         }        
 
         for &dep in elab.pkg_deps[&pkg_id].keys() {
             manifest_paths_recursive(dep, elab, workspace_path, visited, manifest_paths)?;
@@ -643,7 +689,7 @@ fn manifest_paths(elab: &ElaborateWorkspace<'_>) -> CargoResult<Vec<PathBuf>> {
     Ok(manifest_paths)
 }
 
-fn valid_latest_version(requirement: &str, version: &Version) -> bool {
+fn valid_latest_version(mut requirement: &str, version: &Version) -> bool {
     match (requirement.contains('-'), version.is_prerelease()) {
         // if user was on a stable channel, it's unlikely for him to update to an unstable one
         (false, true) => false,
@@ -653,7 +699,8 @@ fn valid_latest_version(requirement: &str, version: &Version) -> bool {
         (false, false) | (true, false) => true,
         // both are unstable, must be in the same channel
         (true, true) => {
-            let requirement_version = Version::parse(requirement).expect("Error could not parse requirement into a semantic version"); 
+            requirement = requirement.trim_start_matches(&['=',' ','~','^'][..]);
+            let requirement_version = Version::parse(&requirement).expect("Error could not parse requirement into a semantic version"); 
             let requirement_channel = requirement_version.pre[0].to_string();
             match (requirement_channel.is_empty(), &version.pre[0]) {
                 (true, &Identifier::Numeric(_)) => true,
